/*
Copyright (C) 2016 Srivats P.

This file is part of "Ostinato"

This is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>
*/

#ifndef _PCAP_TX_STATS_H
#define _PCAP_TX_STATS_H

#include "abstractport.h"

#include <QThread>

struct StatsTuple;

class PcapTxStats : public QThread
{
public:
    PcapTxStats();
    ~PcapTxStats();

    void setTxThreadStats(StatsTuple *stats);

    void useExternalStats(AbstractPort::PortStats *stats);

    void start();
    void stop();
private:
    void run();

    StatsTuple *txThreadStats_;

    bool usingInternalStats_;
    AbstractPort::PortStats *stats_;

    volatile bool stop_;
};

#endif

